@@ -3,7 +3,7 @@
 
 #include <Rcpp.h>
 using namespace Rcpp;
-#include "secr.h"
+#include "poly.h"
 //==============================================================================
 
 NumericVector getpar (
@@ -474,7 +474,7 @@ List simdetectpolycpp (
     int    maybecaught;
     double pks;
     double sumhaz;
-    double *ex;
+    // double *ex;
     
     //========================================================
     // MAIN LINE 
@@ -524,6 +524,7 @@ List simdetectpolycpp (
                 cumd[i+1] = cumd[i] + distance1(line[i], line[i+1]);
             }
         }
+        
     }
     //----------------------------------------------------------------------------
     
@@ -611,7 +612,11 @@ List simdetectpolycpp (
         // -------------------------------------------------------------------------------- 
         // exclusive transect detectors  
         else if (detect == 4) {
-            ex = (double *) R_alloc(10 + 2 * maxvertices, sizeof(double));
+            // ex = (double *) R_alloc(10 + 2 * maxvertices, sizeof(double));
+            // conversions for RMatrix input to integralxDNRcpp
+            const RcppParallel::RMatrix<double> trapsR(traps);
+            const RcppParallel::RMatrix<double> animalsR(animals);
+            
             for (i=0; i<N; i++) {                            // each animal 
                 animal.x = animals[i];
                 animal.y = animals[i + N];
@@ -626,10 +631,11 @@ List simdetectpolycpp (
                                       before, PIA0, gsb0val, PIA1, gsb1val);
                         n1 = cumk[k];
                         n2 = cumk[k+1]-1;
-                        H = hintegral1cpp(fn, gsb);
+                        H = hintegral1Ncpp(fn, as<std::vector<double>>(gsb));
                         for (i=0;i<3;i++) gsbval(0,i) = gsb(i);
+                        const RcppParallel::RMatrix<double> gsbvalR(gsbval);
                         sumhaz += -log(1 - gsb(0) * 
-                            integral1Dcpp (fn, i, 0, gsbval, traps, animals, n1, n2, ex) / H);
+                            integral1DNRcpp (fn, i, 0, gsbvalR, trapsR, animalsR, n1, n2) / H);
                     }
                 }
                 // ------------------------------------ 
@@ -642,10 +648,11 @@ List simdetectpolycpp (
                                       before, PIA0, gsb0val, PIA1, gsb1val);
                         n1 = cumk[k];
                         n2 = cumk[k+1]-1;
-                        H = hintegral1cpp(fn, gsb);
+                        H = hintegral1Ncpp(fn, as<std::vector<double>>(gsb));
                         for (i=0;i<3;i++) gsbval(0,i) = gsb(i);
-                        lambdak = gsb(0) * integral1Dcpp (fn, i, 0, gsbval, traps, animals,
-                                      n1, n2, ex) / H;
+                        const RcppParallel::RMatrix<double> gsbvalR(gsbval);
+                        lambdak = gsb(0) * integral1DNRcpp (fn, i, 0, gsbvalR, trapsR, animalsR,
+                                      n1, n2) / H;
                         pks = (1 - exp(-sumhaz)) * (-log(1-lambdak)) / sumhaz;
                         count = unif_rand() < pks;
                         maxg = 0;
@@ -744,7 +751,9 @@ List simdetectpolycpp (
         // -------------------------------------------------------------------------------- 
         // transect detectors  
         else if (detect == 7) {
-            ex = (double *) R_alloc(10 + 2 * maxvertices, sizeof(double));
+            const RcppParallel::RMatrix<double> trapsR(traps);
+            const RcppParallel::RMatrix<double> animalsR(animals);
+            
             for (i=0; i<N; i++) {                            // each animal 
                 animal.x = animals(i,0);
                 animal.y = animals(i,1);
@@ -756,10 +765,11 @@ List simdetectpolycpp (
                                       before, PIA0, gsb0val, PIA1, gsb1val);
                         n1 = cumk[k];
                         n2 = cumk[k+1]-1;
-                        H = hintegral1cpp(fn, gsb);
+                        H = hintegral1Ncpp(fn, as<std::vector<double>>(gsb));
                         for (i=0;i<3;i++) gsbval(0,i) = gsb(i);
-                        lambdak = gsb(0) * integral1Dcpp (fn, i, 0, gsbval, traps, animals,
-                                      n1, n2, ex) / H;
+                        const RcppParallel::RMatrix<double> gsbvalR(gsbval);
+                        lambdak = gsb(0) * integral1DNRcpp (fn, i, 0, gsbvalR, trapsR, animalsR,
+                                      n1, n2) / H;
                         count = rcount(binomN[s], lambdak, Tski);  // numb detections on transect 
                         maxg = 0;
                         if (count>0) {                       // find maximum - approximate 
